pub struct UdsAgentServerV2 { /* private fields */ }Expand description
v2 agent server over Unix Domain Socket.
Listens on a Unix socket, accepts connections, and dispatches events to an
AgentHandlerV2 implementation using the v2 binary wire format.
Implementations
Sourceimpl UdsAgentServerV2
impl UdsAgentServerV2
Sourcepub fn new(
id: impl Into<String>,
socket_path: impl Into<PathBuf>,
handler: Box<dyn AgentHandlerV2>,
) -> Self
pub fn new( id: impl Into<String>, socket_path: impl Into<PathBuf>, handler: Box<dyn AgentHandlerV2>, ) -> Self
Create a new UDS v2 agent server.
Sourcepub async fn run(&self) -> Result<(), AgentProtocolError>
pub async fn run(&self) -> Result<(), AgentProtocolError>
Start the server.
Removes any stale socket file, binds, and enters an accept loop that spawns a task per connection.